@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,9 +33,9 @@ class MESSAGECOMPOSER_EXPORT FollowUpReminderSelectDateDialog : public QDialog
     Q_OBJECT
 public:
     explicit FollowUpReminderSelectDateDialog(QWidget *parent = nullptr, QAbstractItemModel *model = nullptr);
-    ~FollowUpReminderSelectDateDialog();
+    ~FollowUpReminderSelectDateDialog() override;
 
-    QDate selectedDate() const;
+    Q_REQUIRED_RESULT QDate selectedDate() const;
 
     void accept() override;
 
