@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -173,13 +173,13 @@ QString ImageScaling::generateNewName()
     if (type.isEmpty()) {
         type = QStringLiteral("PNG");
     }
-    if (d->mName.endsWith(QStringLiteral(".png"))) {
+    if (d->mName.endsWith(QLatin1String(".png"))) {
         if (type != QLatin1String("PNG")) {
-            d->mName.replace(QStringLiteral(".png"), QStringLiteral(".jpg"));
+            d->mName.replace(QLatin1String(".png"), QLatin1String(".jpg"));
         }
-    } else if (d->mName.endsWith(QStringLiteral(".jpg"))) {
+    } else if (d->mName.endsWith(QLatin1String(".jpg"))) {
         if (type != QLatin1String("JPG")) {
-            d->mName.replace(QStringLiteral(".jpg"), QStringLiteral(".png"));
+            d->mName.replace(QLatin1String(".jpg"), QLatin1String(".png"));
         }
     } else {
         if (type == QLatin1String("PNG")) {
