@@ -18,8 +18,8 @@
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_AGGREGATION_H__
-#define __MESSAGELIST_CORE_AGGREGATION_H__
+#ifndef MESSAGELIST_CORE_AGGREGATION_H
+#define MESSAGELIST_CORE_AGGREGATION_H
 
 class QDataStream;
 
@@ -27,7 +27,7 @@ class QDataStream;
 #include <QPair>
 #include <QString>
 
-#include <core/optionset.h>
+#include "core/optionset.h"
 
 namespace MessageList {
 namespace Core {
@@ -142,7 +142,7 @@ public:
     /**
     * Returns the currently set Grouping option.
     */
-    Grouping grouping() const;
+    Q_REQUIRED_RESULT Grouping grouping() const;
 
     /**
     * Sets the Grouping option.
@@ -162,7 +162,7 @@ public:
     /**
     * Returns the current GroupExpandPolicy.
     */
-    GroupExpandPolicy groupExpandPolicy() const
+    Q_REQUIRED_RESULT GroupExpandPolicy groupExpandPolicy() const
     {
         return mGroupExpandPolicy;
     }
@@ -187,7 +187,7 @@ public:
     /**
     * Returns the current threading method.
     */
-    Threading threading() const
+    Q_REQUIRED_RESULT Threading threading() const
     {
         return mThreading;
     }
@@ -210,7 +210,7 @@ public:
     /**
     * Returns the current thread leader determination method.
     */
-    ThreadLeader threadLeader() const
+    Q_REQUIRED_RESULT ThreadLeader threadLeader() const
     {
         return mThreadLeader;
     }
@@ -263,7 +263,7 @@ public:
     /**
     * Returns the current fill view strategy.
     */
-    FillViewStrategy fillViewStrategy() const
+    Q_REQUIRED_RESULT FillViewStrategy fillViewStrategy() const
     {
         return mFillViewStrategy;
     }
@@ -296,4 +296,4 @@ public:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_AGGREGATION_H__
+#endif //!__MESSAGELIST_CORE_AGGREGATION_H
