@@ -18,17 +18,15 @@
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_MODEL_H__
-#define __MESSAGELIST_CORE_MODEL_H__
+#ifndef MESSAGELIST_CORE_MODEL_H
+#define MESSAGELIST_CORE_MODEL_H
 
 #include <QAbstractItemModel>
 #include <QList>
 #include <QHash>
 #include <QMultiHash>
 
-#include <core/aggregation.h>
 #include <core/enums.h>
-#include <core/sortorder.h>
 
 #include <time.h> // time_t
 
@@ -45,6 +43,8 @@ class Theme;
 class StorageModel;
 class View;
 class ModelPrivate;
+class SortOrder;
+class Aggregation;
 
 /**
  * This class manages the huge tree of displayable objects: GroupHeaderItems and MessageItems.
@@ -77,7 +77,7 @@ public:
     /**
     * Destroys the mighty model along with the tree of items it manages.
     */
-    ~Model();
+    ~Model() override;
 
     /**
     * Returns the StorageModel currently set.
@@ -222,4 +222,4 @@ private:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MODEL_H__
+#endif //!__MESSAGELIST_CORE_MODEL_H
