@@ -24,7 +24,8 @@
 KMime::Message::Ptr MessageViewer::Test::readAndParseMail(const QString &mailFile)
 {
     QFile file(QStringLiteral(MAIL_DATA_DIR) + QLatin1Char('/') + mailFile);
-    Q_ASSERT(file.open(QIODevice::ReadOnly));
+    const bool openFile = file.open(QIODevice::ReadOnly);
+    Q_ASSERT(openFile);
     const QByteArray data = KMime::CRLFtoLF(file.readAll());
     Q_ASSERT(!data.isEmpty());
     KMime::Message::Ptr msg(new KMime::Message);
