@@ -30,10 +30,11 @@
 
 #include "utils/iconnamecache.h"
 #include "utils/mimetype.h"
+#include "viewer/attachmentstrategy.h"
 #include "viewer/csshelperbase.h"
 #include "messagepartrenderermanager.h"
 
-#include <MimeTreeParser/BufferedHtmlWriter>
+#include "htmlwriter/bufferedhtmlwriter.h"
 #include <MimeTreeParser/MessagePart>
 #include <MimeTreeParser/ObjectTreeParser>
 #include <GrantleeTheme/QtResourceTemplateLoader>
@@ -80,24 +81,31 @@ QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code, G
             switch (status_code) {
             case 0: // GPGME_SIG_STAT_NONE
                 result = i18n("Error: Signature not verified");
+                frameColor = SIG_FRAME_COL_YELLOW;
                 break;
             case 1: // GPGME_SIG_STAT_GOOD
                 result = i18n("Good signature");
+                frameColor = SIG_FRAME_COL_GREEN;
                 break;
             case 2: // GPGME_SIG_STAT_BAD
                 result = i18n("Bad signature");
+                frameColor = SIG_FRAME_COL_RED;
                 break;
             case 3: // GPGME_SIG_STAT_NOKEY
                 result = i18n("No public key to verify the signature");
+                frameColor = SIG_FRAME_COL_RED;
                 break;
             case 4: // GPGME_SIG_STAT_NOSIG
                 result = i18n("No signature found");
+                frameColor = SIG_FRAME_COL_RED;
                 break;
             case 5: // GPGME_SIG_STAT_ERROR
                 result = i18n("Error verifying the signature");
+                frameColor = SIG_FRAME_COL_RED;
                 break;
             case 6: // GPGME_SIG_STAT_DIFF
                 result = i18n("Different results for signatures");
+                frameColor = SIG_FRAME_COL_RED;
                 break;
             /* PENDING(khz) Verify exact meaning of the following values:
             case 7: // GPGME_SIG_STAT_GOOD_EXP
@@ -239,10 +247,10 @@ QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code, G
 
 bool containsExternalReferences(const QString &str, const QString &extraHead)
 {
-    const bool hasBaseInHeader = extraHead.contains(QStringLiteral(
+    const bool hasBaseInHeader = extraHead.contains(QLatin1String(
                                                         "<base href=\""), Qt::CaseInsensitive);
-    if (hasBaseInHeader && (str.contains(QStringLiteral("href=\"/"), Qt::CaseInsensitive)
-                            || str.contains(QStringLiteral("<img src=\"/"), Qt::CaseInsensitive))) {
+    if (hasBaseInHeader && (str.contains(QLatin1String("href=\"/"), Qt::CaseInsensitive)
+                            || str.contains(QLatin1String("<img src=\"/"), Qt::CaseInsensitive))) {
         return true;
     }
     int httpPos = str.indexOf(QLatin1String("\"http:"), Qt::CaseInsensitive);
@@ -286,19 +294,21 @@ bool containsExternalReferences(const QString &str, const QString &extraHead)
 // this at all...
 QString processHtml(const QString &htmlSource, QString &extraHead)
 {
-    auto s = htmlSource.trimmed();
+    QString s = htmlSource.trimmed();
     s = s.replace(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
     s = s.replace(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
 
     // head
     s = s.replace(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive), QString()).trimmed();
-    if (s.startsWith(QLatin1String("<head>", Qt::CaseInsensitive))) {
-        const auto idx = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
-        if (idx < 0) {
+    const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
+    if (startIndex >= 0) {
+        const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
+
+        if (endIndex < 0) {
             return htmlSource;
         }
-        extraHead = s.mid(6, idx - 6);
-        s = s.mid(idx + 7).trimmed();
+        extraHead = s.mid(startIndex + 6 , endIndex - startIndex - 6);
+        s = s.mid(endIndex + 7).trimmed();
     }
 
     // body
@@ -308,12 +318,10 @@ QString processHtml(const QString &htmlSource, QString &extraHead)
     return s;
 }
 
-DefaultRendererPrivate::DefaultRendererPrivate(const MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper, HtmlWriter *writer, const MessagePartRendererFactory *rendererFactory)
-    : mMsgPart(msgPart)
-    , mCSSHelper(cssHelper)
+DefaultRendererPrivate::DefaultRendererPrivate(CSSHelperBase *cssHelper, const MessagePartRendererFactory *rendererFactory)
+    : mCSSHelper(cssHelper)
     , mRendererFactory(rendererFactory)
 {
-    renderFactory(mMsgPart, writer);
 }
 
 DefaultRendererPrivate::~DefaultRendererPrivate()
@@ -360,7 +368,6 @@ void DefaultRendererPrivate::render(const MimeMessagePart::Ptr &mp, HtmlWriter *
     if (mp->isAttachment()) {
         aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
-
     if (mp->isRoot()) {
         rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
     }
@@ -379,9 +386,9 @@ void DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp
 
     c.insert(QStringLiteral("block"), &block);
     block.setProperty("link",
-                      mp->nodeHelper()->asHREF(mp->mMessage.data(), QStringLiteral("body")));
+                      mp->nodeHelper()->asHREF(mp->message().data(), QStringLiteral("body")));
 
-    c.insert(QStringLiteral("msgHeader"), mp->source()->createMessageHeader(mp->mMessage.data()));
+    c.insert(QStringLiteral("msgHeader"), mCreateMessageHeader(mp->message().data()));
     c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
         renderSubParts(mp, htmlWriter);
     }));
@@ -404,15 +411,14 @@ void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *
     c.insert(QStringLiteral("block"), &block);
 
     auto preferredMode = mp->source()->preferredMode();
-    bool isHtmlPreferred = (preferredMode == Util::Html) || (preferredMode == Util::MultipartHtml);
-    const bool isPrinting = mp->source()->isPrinting();
+    const bool isHtmlPreferred = (preferredMode == MimeTreeParser::Util::Html) || (preferredMode == MimeTreeParser::Util::MultipartHtml);
     block.setProperty("htmlMail", isHtmlPreferred);
-    block.setProperty("loadExternal", mp->source()->htmlLoadExternal());
-    block.setProperty("isPrinting", isPrinting);
+    block.setProperty("loadExternal", htmlLoadExternal());
+    block.setProperty("isPrinting", isPrinting());
     {
         QString extraHead;
         //laurent: FIXME port to async method webengine
-        QString bodyText = processHtml(mp->mBodyHTML, extraHead);
+        QString bodyText = processHtml(mp->bodyHtml(), extraHead);
 
         if (isHtmlPreferred) {
             mp->nodeHelper()->setNodeDisplayedEmbedded(mp->content(), true);
@@ -426,12 +432,12 @@ void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *
 
     {
         ConvertHtmlToPlainText convert;
-        convert.setHtmlString(mp->mBodyHTML);
+        convert.setHtmlString(mp->bodyHtml());
         QString plaintext = convert.generatePlainText();
         plaintext.replace(QLatin1Char('\n'), QStringLiteral("<br>"));
         c.insert(QStringLiteral("plaintext"), plaintext);
     }
-    mp->source()->setHtmlMode(Util::Html, QList<Util::HtmlMode>() << Util::Html << Util::Normal);
+    mp->source()->setHtmlMode(MimeTreeParser::Util::Html, QList<MimeTreeParser::Util::HtmlMode>() << MimeTreeParser::Util::Html << MimeTreeParser::Util::Normal);
 
     HTMLBlock::Ptr aBlock;
     if (mp->isAttachment()) {
@@ -465,13 +471,14 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
         }));
     }
 
-    c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(mp->mCryptoProto));
-    if (!mp->mDecryptRecipients.empty()) {
+    c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(mp->cryptoProto()));
+    if (!mp->decryptRecipients().empty()) {
         c.insert(QStringLiteral("decryptedRecipients"),
-                 QVariant::fromValue(mp->mDecryptRecipients));
+                 QVariant::fromValue(mp->decryptRecipients()));
     }
     c.insert(QStringLiteral("block"), &block);
 
+    block.setProperty("isPrinting", isPrinting());
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("isDecrypted", mp->decryptMessage());
     block.setProperty("isDecryptable", metaData.isDecryptable);
@@ -480,7 +487,7 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
                                                                                   "document-decrypt"),
                                                                               KIconLoader::Small)).url());
     block.setProperty("errorText", metaData.errorText);
-    block.setProperty("noSecKey", mp->mNoSecKey);
+    block.setProperty("noSecKey", mp->isNoSecKey());
 
     Grantlee::OutputStream s(htmlWriter->stream());
     t->render(&s, &c);
@@ -490,7 +497,7 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
 {
     KMime::Content *node = mp->content();
     const auto metaData = *mp->partMetaData();
-    auto cryptoProto = mp->mCryptoProto;
+    auto cryptoProto = mp->cryptoProto();
 
     const bool isSMIME = cryptoProto && (cryptoProto == QGpgME::smime());
 
@@ -519,8 +526,8 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("errorText", metaData.errorText);
 
-    block.setProperty("detailHeader", mp->source()->showSignatureDetails());
-    block.setProperty("printing", false);
+    block.setProperty("detailHeader", showSignatureDetails());
+    block.setProperty("isPrinting", isPrinting());
     block.setProperty("addr", metaData.signerMailAddresses.join(QLatin1Char(',')));
     block.setProperty("technicalProblem", metaData.technicalProblem);
     block.setProperty("keyId", metaData.keyId);
@@ -626,7 +633,7 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
                 mClass = QStringLiteral("signOkKeyOk");
                 // extra hint for green case
                 // that email addresses in DN do not match fromAddress
-                QString msgFrom(KEmailAddress::extractEmailAddress(mp->mFromAddress));
+                QString msgFrom(KEmailAddress::extractEmailAddress(mp->fromAddress()));
                 QString certificate;
                 if (metaData.keyId.isEmpty()) {
                     certificate = i18n("certificate");
@@ -641,8 +648,8 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
                               +i18nc("Start of warning message.", "Warning:")
                               +QStringLiteral("</u> ")
                               +i18n(
-                            "Sender's mail address is not stored in the %1 used for signing.",
-                            certificate)
+                                  "Sender's mail address is not stored in the %1 used for signing.",
+                                  certificate)
                               +QStringLiteral("<br />")
                               +i18n("sender: ")
                               +msgFrom
@@ -657,7 +664,7 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
                         for (QStringList::ConstIterator it = blockAddrs.constBegin();
                              it != end; ++it) {
                             if (!bStart) {
-                                greenCaseWarning.append(QStringLiteral(", <br />&nbsp; &nbsp;"));
+                                greenCaseWarning.append(QLatin1String(", <br />&nbsp; &nbsp;"));
                             }
 
                             bStart = false;
@@ -791,9 +798,9 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
             }
         }
     }
-    MimeMessagePart::Ptr part(mp->mChildParts.first());
-    if (mp->mChildParts.contains(mode)) {
-        part = mp->mChildParts[mode];
+    MimeMessagePart::Ptr part(mp->childParts().first());
+    if (mp->childParts().contains(mode)) {
+        part = mp->childParts()[mode];
     }
 
     render(part, htmlWriter);
@@ -801,7 +808,7 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
 
 void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    const GpgME::ImportResult &importResult(mp->mImportResult);
+    const GpgME::ImportResult &importResult(mp->importResult());
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
                                                                                              ":/certmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
@@ -851,6 +858,16 @@ void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, Html
 {
     const QString className = QString::fromUtf8(msgPart->metaObject()->className());
 
+    if (isHiddenHint(msgPart)) {
+        QByteArray cid = msgPart->content()->contentID()->identifier();
+        auto mp = msgPart.dynamicCast<MimeTreeParser::TextMessagePart>();
+        if (!cid.isEmpty() && mp) {
+            QString fileName = mp->temporaryFilePath();
+            QString href = QUrl::fromLocalFile(fileName).url();
+            htmlWriter->embedPart(cid, href);
+        }
+    }
+
     if (renderWithFactory(msgPart, htmlWriter)) {
         return;
     }
@@ -901,8 +918,166 @@ void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, Html
     }
 }
 
-DefaultRenderer::DefaultRenderer(const MimeTreeParser::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper, MimeTreeParser::HtmlWriter *writer)
-    : d(new MimeTreeParser::DefaultRendererPrivate(msgPart, cssHelper, writer, MessagePartRendererFactory::instance()))
+bool DefaultRendererPrivate::isHiddenHint(const MimeTreeParser::MessagePart::Ptr &msgPart)
+{
+    auto mp = msgPart.dynamicCast<MimeTreeParser::MessagePart>();
+    auto content = msgPart->content();
+
+    if (!mp || !content) {
+        return false;
+    }
+
+    if (mShowOnlyOneMimePart && mMsgPart.data() == msgPart->parentPart()) {
+        if (mMsgPart->subParts().at(0) == msgPart.data()) {
+            return false;
+        }
+    }
+
+    if (msgPart->nodeHelper()->isNodeDisplayedHidden(content)) {
+        return true;
+    }
+
+    const AttachmentStrategy *const as = mAttachmentStrategy;
+    const bool defaultHidden(as && as->defaultDisplay(content) == AttachmentStrategy::None);
+    auto preferredMode = source()->preferredMode();
+    bool isHtmlPreferred = (preferredMode == MimeTreeParser::Util::Html) || (preferredMode == MimeTreeParser::Util::MultipartHtml);
+
+    QByteArray mediaType("text");
+    if (content->contentType(false) && !content->contentType()->mediaType().isEmpty()
+        && !content->contentType()->subType().isEmpty()) {
+        mediaType = content->contentType()->mediaType();
+    }
+    const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
+
+    bool defaultAsIcon = true;
+    if (!mp->neverDisplayInline()) {
+        if (as) {
+            defaultAsIcon = as->defaultDisplay(content) == AttachmentStrategy::AsIcon;
+        }
+    }
+
+    // neither image nor text -> show as icon
+    if (!mp->isImage() && !isTextPart) {
+        defaultAsIcon = true;
+    }
+
+    bool hidden(false);
+    if (isTextPart) {
+        hidden = defaultHidden;
+    } else {
+        if (mp->isImage() && isHtmlPreferred
+            && content->parent() && content->parent()->contentType(false)->subType() == "related") {
+            hidden = true;
+        } else {
+            hidden = defaultHidden && content->parent();
+            hidden |= defaultAsIcon && defaultHidden;
+        }
+    }
+    msgPart->nodeHelper()->setNodeDisplayedHidden(content, hidden);
+    return hidden;
+}
+
+MimeTreeParser::IconType DefaultRendererPrivate::displayHint(const MimeTreeParser::MessagePart::Ptr &msgPart)
+{
+    auto mp = msgPart.dynamicCast<MimeTreeParser::TextMessagePart>();
+    auto content = msgPart->content();
+
+    if (!content || !mp) {
+        return MimeTreeParser::IconType::NoIcon;
+    }
+
+    const AttachmentStrategy *const as = mAttachmentStrategy;
+    const bool defaultDisplayHidden(as && as->defaultDisplay(content) == AttachmentStrategy::None);
+    const bool defaultDisplayInline(as && as->defaultDisplay(content) == AttachmentStrategy::Inline);
+    const bool defaultDisplayAsIcon(as && as->defaultDisplay(content) == AttachmentStrategy::AsIcon);
+    const bool showOnlyOneMimePart(mShowOnlyOneMimePart);
+    auto preferredMode = source()->preferredMode();
+    bool isHtmlPreferred = (preferredMode == MimeTreeParser::Util::Html) || (preferredMode == MimeTreeParser::Util::MultipartHtml);
+
+    QByteArray mediaType("text");
+    if (content->contentType(false) && !content->contentType()->mediaType().isEmpty()
+        && !content->contentType()->subType().isEmpty()) {
+        mediaType = content->contentType()->mediaType();
+    }
+    const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
+
+    bool defaultAsIcon = true;
+    if (!mp->neverDisplayInline()) {
+        if (as) {
+            defaultAsIcon = defaultDisplayAsIcon;
+        }
+    }
+    if (mp->isImage() && showOnlyOneMimePart && !mp->neverDisplayInline()) {
+        defaultAsIcon = false;
+    }
+
+    // neither image nor text -> show as icon
+    if (!mp->isImage() && !isTextPart) {
+        defaultAsIcon = true;
+    }
+
+    if (isTextPart) {
+        if (as && !defaultDisplayInline) {
+            return MimeTreeParser::IconExternal;
+        }
+        return MimeTreeParser::NoIcon;
+    } else {
+        if (mp->isImage() && isHtmlPreferred
+            && content->parent() && content->parent()->contentType(false)->subType() == "related") {
+            return MimeTreeParser::IconInline;
+        }
+
+        if (defaultDisplayHidden && !showOnlyOneMimePart && content->parent()) {
+            return MimeTreeParser::IconInline;
+        }
+
+        if (defaultAsIcon) {
+            return MimeTreeParser::IconExternal;
+        } else if (mp->isImage()) {
+            return MimeTreeParser::IconInline;
+        }
+    }
+
+    return MimeTreeParser::NoIcon;
+}
+
+bool DefaultRendererPrivate::showEmoticons() const
+{
+    return mShowEmoticons;
+}
+
+bool DefaultRendererPrivate::isPrinting() const
+{
+    return mIsPrinting;
+}
+
+bool DefaultRendererPrivate::htmlLoadExternal() const
+{
+    return mHtmlLoadExternal;
+}
+
+bool DefaultRendererPrivate::showExpandQuotesMark() const
+{
+    return mShowExpandQuotesMark;
+}
+
+bool DefaultRendererPrivate::showOnlyOneMimePart() const
+{
+    return mShowOnlyOneMimePart;
+}
+
+bool DefaultRendererPrivate::showSignatureDetails() const
+{
+    return mShowSignatureDetails;
+}
+
+int DefaultRendererPrivate::levelQuote() const
+{
+    return mLevelQuote;
+}
+
+DefaultRenderer::DefaultRenderer(CSSHelperBase *cssHelper)
+    : d(new DefaultRendererPrivate(cssHelper, MessagePartRendererFactory::instance()))
 {
 }
 
@@ -910,3 +1085,70 @@ DefaultRenderer::~DefaultRenderer()
 {
     delete d;
 }
+
+void DefaultRenderer::setShowOnlyOneMimePart(bool onlyOneMimePart)
+{
+    d->mShowOnlyOneMimePart = onlyOneMimePart;
+}
+
+void DefaultRenderer::setAttachmentStrategy(const AttachmentStrategy *strategy)
+{
+    d->mAttachmentStrategy = strategy;
+}
+
+void DefaultRenderer::setShowEmoticons(bool showEmoticons)
+{
+    d->mShowEmoticons = showEmoticons;
+}
+
+void DefaultRenderer::setIsPrinting(bool isPrinting)
+{
+    d->mIsPrinting = isPrinting;
+}
+
+void DefaultRenderer::setShowExpandQuotesMark(bool showExpandQuotesMark)
+{
+    d->mShowExpandQuotesMark = showExpandQuotesMark;
+}
+
+void DefaultRenderer::setShowSignatureDetails(bool showSignatureDetails)
+{
+    d->mShowSignatureDetails = showSignatureDetails;
+}
+
+void DefaultRenderer::setLevelQuote(int levelQuote)
+{
+    d->mLevelQuote = levelQuote;
+}
+
+void DefaultRenderer::setHtmlLoadExternal(bool htmlLoadExternal)
+{
+    d->mHtmlLoadExternal = htmlLoadExternal;
+}
+
+void DefaultRenderer::setCreateMessageHeader(std::function<QString(KMime::Message *)> createMessageHeader)
+{
+    d->mCreateMessageHeader = createMessageHeader;
+}
+
+QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QString indent)
+{
+    const QString line
+        = QStringLiteral("%1 * %3\n").arg(indent,
+                                          QString::fromUtf8(messagePart->metaObject()->className()));
+    QString ret = line;
+
+    indent += QStringLiteral(" ");
+    foreach (const auto &subPart, messagePart->subParts()) {
+        ret += renderTreeHelper(subPart, indent);
+    }
+    return ret;
+}
+
+void DefaultRenderer::render(const MimeTreeParser::MessagePart::Ptr &msgPart, HtmlWriter *writer)
+{
+    qCDebug(MESSAGEVIEWER_LOG) << "MimeTreeParser structure:";
+    qCDebug(MESSAGEVIEWER_LOG) << qPrintable(renderTreeHelper(msgPart, QString()));
+    d->mMsgPart = msgPart;
+    d->renderFactory(d->mMsgPart, writer);
+}
