@@ -17,29 +17,46 @@
    02110-1301, USA.
 */
 
-#ifndef __MESSAGEVIEWER_DEFAULTRENDERER_H__
-#define __MESSAGEVIEWER_DEFAULTRENDERER_H__
+#ifndef MESSAGEVIEWER_DEFAULTRENDERER_H
+#define MESSAGEVIEWER_DEFAULTRENDERER_H
 
 #include <QSharedPointer>
 
+#include <functional>
+
+namespace KMime {
+class Message;
+}
+
 namespace MimeTreeParser {
-class DefaultRendererPrivate;
-class HtmlWriter;
 class MessagePart;
 typedef QSharedPointer<MessagePart> MessagePartPtr;
 }
 
 namespace MessageViewer {
+class DefaultRendererPrivate;
+class HtmlWriter;
+class AttachmentStrategy;
 class CSSHelperBase;
 
 class DefaultRenderer
 {
 public:
-    DefaultRenderer(const MimeTreeParser::MessagePartPtr &msgPart, CSSHelperBase *cssHelder, MimeTreeParser::HtmlWriter *writer);
+    DefaultRenderer(CSSHelperBase *cssHelder);
     ~DefaultRenderer();
 
+    void setShowOnlyOneMimePart(bool onlyOneMimePart);
+    void setAttachmentStrategy(const AttachmentStrategy *strategy);
+    void setShowEmoticons(bool showEmoticons);
+    void setIsPrinting(bool isPrinting);
+    void setShowExpandQuotesMark(bool showExpandQuotesMark);
+    void setShowSignatureDetails(bool showSignatureDetails);
+    void setLevelQuote(int levelQuote);
+    void setHtmlLoadExternal(bool htmlLoadExternal);
+    void setCreateMessageHeader(std::function<QString(KMime::Message *)>);
+    void render(const MimeTreeParser::MessagePartPtr &msgPart, HtmlWriter *writer);
 private:
-    MimeTreeParser::DefaultRendererPrivate *d;
+    DefaultRendererPrivate *d;
 };
 }
-#endif //__MIMETREEPARSER_MAILRENDERER_H__
+#endif //__MESSAGEVIEWER_MAILRENDERER_H
