@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,7 +33,7 @@ public:
     explicit ScamCheckShortUrlManager(QObject *parent = nullptr);
     ~ScamCheckShortUrlManager();
     static ScamCheckShortUrlManager *self();
-    ScamCheckShortUrl *scamCheckShortUrl() const;
+    Q_REQUIRED_RESULT ScamCheckShortUrl *scamCheckShortUrl() const;
 private:
     ScamCheckShortUrlManagerPrivate *const d;
 };
