@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -76,8 +76,7 @@ void ScamExpandUrlJob::expandedUrl(const QUrl &url)
     QNetworkReply *reply = d->mNetworkAccessManager->get(QNetworkRequest(newUrl));
     reply->setProperty("shortUrl", url.url());
     connect(reply,
-            static_cast<void (QNetworkReply::*)(
-                            QNetworkReply::NetworkError)>(&QNetworkReply::error), this,
+            QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this,
             &ScamExpandUrlJob::slotError);
 }
 
