@@ -30,10 +30,12 @@
 */
 
 #include "csshelperbase.h"
+#include "utils/iconnamecache.h"
 
 #include <QApplication>
 #include <QPaintDevice>
 #include <QPalette>
+#include <QUrl>
 
 namespace MessageViewer {
 namespace {
@@ -74,6 +76,10 @@ CSSHelperBase::CSSHelperBase(const QPaintDevice *pd)
     , mPaintDevice(pd)
 {
     recalculatePGPColors();
+    const QString imgSrcShow = QStringLiteral("quicklistOpened.png");
+    const QString imgSrcHide = QStringLiteral("quicklistClosed.png");
+    imgShowUrl = QUrl::fromLocalFile(MessageViewer::IconNameCache::instance()->iconPathFromLocal(imgSrcShow)).url();
+    imgHideUrl = QUrl::fromLocalFile(MessageViewer::IconNameCache::instance()->iconPathFromLocal(imgSrcHide)).url();
 }
 
 CSSHelperBase::~CSSHelperBase()
@@ -192,6 +198,22 @@ QString CSSHelperBase::quoteFontTag(int level) const
     }
 }
 
+QString CSSHelperBase::fullAddressList() const
+{
+    QString css = QStringLiteral("input[type=checkbox].addresslist_checkbox {display: none}\n"
+                                 ".addresslist_label_short {border: 1px; border-radius: 5px; padding: 0px 10px 0px 10px; white-space: nowrap}\n"
+                                 ".addresslist_label_full {border: 1px; border-radius: 5px; padding: 0px 10px 0px 10px; white-space: nowrap}\n");
+    css += QStringLiteral(".addresslist_label_short {background-image:url(%1);\nbackground-repeat: no-repeat}\n").arg(imgShowUrl);
+    css += QStringLiteral(".addresslist_label_full {background-image:url(%1);\nbackground-repeat: no-repeat}\n\n").arg(imgHideUrl);
+    for (const QString &str : {QStringLiteral("Cc"), QStringLiteral("To"), QStringLiteral("Bcc")}) {
+        css += QStringLiteral("input ~ span.fullFull%1AddressList {display: block}\n"
+                              "input ~ span.shortFull%1AddressList {display: none}\n"
+                              "input:checked ~ span.fullFull%1AddressList {display: none}\n"
+                              "input:checked ~ span.shortFull%1AddressList {display: block}\n\n").arg(str);
+    }
+    return css;
+}
+
 QString CSSHelperBase::nonQuotedFontTag() const
 {
     return QStringLiteral("<div class=\"noquote\">");
@@ -224,6 +246,7 @@ QString CSSHelperBase::printCssDefinitions(bool fixed) const
                                .arg(mPrintFont.family())
                                .arg(mPrintFont.pointSize());
     const QPalette &pal = QApplication::palette();
+    const QString linkColor = mLinkColor.name();
 
     const QFont printFont = bodyFont(fixed, true /* print */);
     QString quoteCSS;
@@ -248,7 +271,11 @@ QString CSSHelperBase::printCssDefinitions(bool fixed) const
         .arg(printFont.family(),
              QString::number(printFont.pointSize()))
         +
-        QStringLiteral("tr.textAtmH,\n"
+        QStringLiteral("a {\n"
+                       "  color: %4 ! important;\n"
+                       "  text-decoration: none ! important;\n"
+                       "}\n\n"
+                       "tr.textAtmH,\n"
                        "tr.signInProgressH,\n"
                        "tr.rfc822H,\n"
                        "tr.encrH,\n"
@@ -306,8 +333,9 @@ QString CSSHelperBase::printCssDefinitions(bool fixed) const
                        )
         .arg(headerFont,
              pal.color(QPalette::Background).name(),
-             pal.color(QPalette::Foreground).name())
-        + quoteCSS;
+             pal.color(QPalette::Foreground).name(),
+             linkColor)
+        + quoteCSS + fullAddressList();
 }
 
 QString CSSHelperBase::quoteCssDefinition() const
@@ -597,7 +625,7 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
              pal.color(QPalette::Foreground).name(),
              pal.color(QPalette::Background).name())
         .arg(pal.color(QPalette::Mid).name())
-        + quoteCSS;
+        + quoteCSS + fullAddressList();
 }
 
 QString CSSHelperBase::commonCssDefinitions() const
@@ -707,16 +735,6 @@ QString CSSHelperBase::commonCssDefinitions() const
                        "  background-color: transparent ! important;\n"
                        "}\n\n"
 
-                       "span.pimsmileytext {\n"
-                       "  position: absolute;\n"
-                       "  top: 0px;\n"
-                       "  left: 0px;\n"
-                       "  visibility: hidden;\n"
-                       "}\n\n"
-
-                       "img.pimsmileyimg {\n"
-                       "}\n\n"
-
                        "div.quotelevelmark {\n"
                        "  position: absolute;\n"
                        "  margin-left:-10px;\n"
