@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,13 +24,7 @@
 
 namespace MessageViewer {
 namespace MailWebEngineScript {
-MESSAGEVIEWER_EXPORT QString injectAttachments(const QString &delayedHtml, const QString &element);
-MESSAGEVIEWER_EXPORT QString replaceInnerHtml(const QString &field, const QString &html);
-MESSAGEVIEWER_EXPORT QString manageShowHideAttachments(bool hide);
-MESSAGEVIEWER_EXPORT QString manageShowHideToAddress(bool hide);
-MESSAGEVIEWER_EXPORT QString manageShowHideCcAddress(bool hide);
 MESSAGEVIEWER_EXPORT QString manageShowHideEncryptionDetails(bool hide);
-MESSAGEVIEWER_EXPORT QString createShowHideAddressScript(const QString &field, bool hide);
 }
 }
 #endif // MAILWEBENGINESCRIPT_H
