@@ -19,7 +19,6 @@
 
 #include "messagepart.h"
 #include "mimetreeparser_debug.h"
-#include "attachmentstrategy.h"
 #include "cryptohelper.h"
 #include "objecttreeparser.h"
 #include "job/qgpgmejobexecutor.h"
@@ -62,6 +61,8 @@ public:
     QString mText;
     PartMetaData mMetaData;
     bool mRoot = false;
+    bool mIsImage = false;
+    bool mNeverDisplayInline = false;
 };
 }
 
@@ -181,11 +182,6 @@ bool MessagePart::isHtml() const
     return false;
 }
 
-bool MessagePart::isHidden() const
-{
-    return false;
-}
-
 Interface::ObjectTreeSource *MessagePart::source() const
 {
     Q_ASSERT(mOtp);
@@ -247,6 +243,26 @@ void MessagePart::clearSubParts()
     d->mBlocks.clear();
 }
 
+bool MessagePart::neverDisplayInline() const
+{
+    return d->mNeverDisplayInline;
+}
+
+void MessagePart::setNeverDisplayInline(bool displayInline)
+{
+    d->mNeverDisplayInline = displayInline;
+}
+
+bool MessagePart::isImage() const
+{
+    return d->mIsImage;
+}
+
+void MessagePart::setIsImage(bool image)
+{
+    d->mIsImage = image;
+}
+
 //-----MessagePartList----------------------
 MessagePartList::MessagePartList(ObjectTreeParser *otp)
     : MessagePart(otp, QString())
@@ -274,11 +290,9 @@ QString MessagePartList::htmlContent() const
 
 //-----TextMessageBlock----------------------
 
-TextMessagePart::TextMessagePart(ObjectTreeParser *otp, KMime::Content *node, bool drawFrame, bool decryptMessage)
+TextMessagePart::TextMessagePart(ObjectTreeParser *otp, KMime::Content *node, bool decryptMessage)
     : MessagePartList(otp)
-    , mDrawFrame(drawFrame)
     , mDecryptMessage(decryptMessage)
-    , mIsHidden(false)
 {
     if (!node) {
         qCWarning(MIMETREEPARSER_LOG) << "not a valid node";
@@ -286,7 +300,6 @@ TextMessagePart::TextMessagePart(ObjectTreeParser *otp, KMime::Content *node, bo
     }
 
     setContent(node);
-    mIsHidden = mOtp->nodeHelper()->isNodeDisplayedHidden(node);
 
     parseContent();
 }
@@ -387,24 +400,19 @@ KMMsgSignatureState TextMessagePart::signatureState() const
     return mSignatureState;
 }
 
-bool TextMessagePart::isHidden() const
-{
-    return mIsHidden;
-}
-
 bool TextMessagePart::showLink() const
 {
     return !temporaryFilePath().isEmpty();
 }
 
-bool TextMessagePart::showTextFrame() const
+bool TextMessagePart::isFirstTextPart() const
 {
-    return mDrawFrame;
+    return content()->topLevel()->textContent() == content();
 }
 
-void TextMessagePart::setShowTextFrame(bool showFrame)
+bool TextMessagePart::hasLabel() const
 {
-    mDrawFrame = showFrame;
+    return !NodeHelper::fileName(content()).isEmpty();
 }
 
 QString TextMessagePart::label() const
@@ -433,10 +441,8 @@ QString TextMessagePart::temporaryFilePath() const
 
 //-----AttachmentMessageBlock----------------------
 
-AttachmentMessagePart::AttachmentMessagePart(ObjectTreeParser *otp, KMime::Content *node, bool drawFrame, bool decryptMessage)
-    : TextMessagePart(otp, node, drawFrame, decryptMessage)
-    , mIsImage(false)
-    , mNeverDisplayInline(false)
+AttachmentMessagePart::AttachmentMessagePart(ObjectTreeParser *otp, KMime::Content *node, bool decryptMessage)
+    : TextMessagePart(otp, node, decryptMessage)
 {
 }
 
@@ -444,126 +450,6 @@ AttachmentMessagePart::~AttachmentMessagePart()
 {
 }
 
-bool AttachmentMessagePart::neverDisplayInline() const
-{
-    return mNeverDisplayInline;
-}
-
-void AttachmentMessagePart::setNeverDisplayInline(bool displayInline)
-{
-    mNeverDisplayInline = displayInline;
-}
-
-bool AttachmentMessagePart::isImage() const
-{
-    return mIsImage;
-}
-
-void AttachmentMessagePart::setIsImage(bool image)
-{
-    mIsImage = image;
-}
-
-IconType AttachmentMessagePart::asIcon() const
-{
-    const AttachmentStrategy *const as = mOtp->attachmentStrategy();
-    const bool defaultHidden(as && as->defaultDisplay(content()) == AttachmentStrategy::None);
-    const bool showOnlyOneMimePart(mOtp->showOnlyOneMimePart());
-    auto preferredMode = source()->preferredMode();
-    bool isHtmlPreferred = (preferredMode == Util::Html) || (preferredMode == Util::MultipartHtml);
-
-    QByteArray mediaType("text");
-    if (content()->contentType(false) && !content()->contentType()->mediaType().isEmpty()
-        && !content()->contentType()->subType().isEmpty()) {
-        mediaType = content()->contentType()->mediaType();
-    }
-    const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
-
-    bool defaultAsIcon = true;
-    if (!neverDisplayInline()) {
-        if (as) {
-            defaultAsIcon = as->defaultDisplay(content()) == AttachmentStrategy::AsIcon;
-        }
-    }
-    if (isImage() && showOnlyOneMimePart && !neverDisplayInline()) {
-        defaultAsIcon = false;
-    }
-
-    // neither image nor text -> show as icon
-    if (!isImage() && !isTextPart) {
-        defaultAsIcon = true;
-    }
-
-    if (isTextPart) {
-        if (as && as->defaultDisplay(content()) != AttachmentStrategy::Inline) {
-            return MimeTreeParser::IconExternal;
-        }
-        return MimeTreeParser::NoIcon;
-    } else {
-        if (isImage() && isHtmlPreferred
-            && content()->parent() && content()->parent()->contentType()->subType() == "related") {
-            return MimeTreeParser::IconInline;
-        }
-
-        if (defaultHidden && !showOnlyOneMimePart && content()->parent()) {
-            return MimeTreeParser::IconInline;
-        }
-
-        if (defaultAsIcon) {
-            return MimeTreeParser::IconExternal;
-        } else if (isImage()) {
-            return MimeTreeParser::IconInline;
-        } else {
-            return MimeTreeParser::NoIcon;
-        }
-    }
-}
-
-bool AttachmentMessagePart::isHidden() const
-{
-    if (mOtp->showOnlyOneMimePart()) {
-        return false; // never hide when only showing one part, otherwise you'll see nothing
-    }
-    const AttachmentStrategy *const as = mOtp->attachmentStrategy();
-    const bool defaultHidden(as && as->defaultDisplay(content()) == AttachmentStrategy::None);
-    auto preferredMode = source()->preferredMode();
-    bool isHtmlPreferred = (preferredMode == Util::Html) || (preferredMode == Util::MultipartHtml);
-
-    QByteArray mediaType("text");
-    if (content()->contentType(false) && !content()->contentType()->mediaType().isEmpty()
-        && !content()->contentType()->subType().isEmpty()) {
-        mediaType = content()->contentType()->mediaType();
-    }
-    const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
-
-    bool defaultAsIcon = true;
-    if (!neverDisplayInline()) {
-        if (as) {
-            defaultAsIcon = as->defaultDisplay(content()) == AttachmentStrategy::AsIcon;
-        }
-    }
-
-    // neither image nor text -> show as icon
-    if (!isImage() && !isTextPart) {
-        defaultAsIcon = true;
-    }
-
-    bool hidden(false);
-    if (isTextPart) {
-        hidden = defaultHidden;
-    } else {
-        if (isImage() && isHtmlPreferred
-            && content()->parent() && content()->parent()->contentType()->subType() == "related") {
-            hidden = true;
-        } else {
-            hidden = defaultHidden && content()->parent();
-            hidden |= defaultAsIcon && defaultHidden;
-        }
-    }
-    mOtp->nodeHelper()->setNodeDisplayedHidden(content(), hidden);
-    return hidden;
-}
-
 //-----HtmlMessageBlock----------------------
 
 HtmlMessagePart::HtmlMessagePart(ObjectTreeParser *otp, KMime::Content *node, Interface::ObjectTreeSource *source)
@@ -601,6 +487,11 @@ bool HtmlMessagePart::isHtml() const
     return true;
 }
 
+QString HtmlMessagePart::bodyHtml() const
+{
+    return mBodyHTML;
+}
+
 //-----MimeMessageBlock----------------------
 
 MimeMessagePart::MimeMessagePart(ObjectTreeParser *otp, KMime::Content *node, bool onlyOneMimePart)
@@ -696,6 +587,11 @@ Util::HtmlMode AlternativeMessagePart::preferredMode() const
     return mPreferredMode;
 }
 
+void AlternativeMessagePart::setPreferredMode(Util::HtmlMode preferredMode)
+{
+    mPreferredMode = preferredMode;
+}
+
 QList<Util::HtmlMode> AlternativeMessagePart::availableModes()
 {
     return mChildParts.keys();
@@ -721,6 +617,11 @@ void AlternativeMessagePart::fix() const
     }
 }
 
+const QMap<Util::HtmlMode, MimeMessagePart::Ptr> &AlternativeMessagePart::childParts() const
+{
+    return mChildParts;
+}
+
 bool AlternativeMessagePart::isHtml() const
 {
     return mChildParts.contains(Util::MultipartHtml);
@@ -773,6 +674,11 @@ QString CertMessagePart::text() const
     return QString();
 }
 
+const GpgME::ImportResult &CertMessagePart::importResult() const
+{
+    return mImportResult;
+}
+
 //-----SignedMessageBlock---------------------
 SignedMessagePart::SignedMessagePart(ObjectTreeParser *otp, const QString &text, const QGpgME::Protocol *cryptoProto, const QString &fromAddress, KMime::Content *node)
     : MessagePart(otp, text)
@@ -1089,6 +995,16 @@ QString SignedMessagePart::htmlContent() const
     }
 }
 
+const QGpgME::Protocol *SignedMessagePart::cryptoProto() const
+{
+    return mCryptoProto;
+}
+
+QString SignedMessagePart::fromAddress() const
+{
+    return mFromAddress;
+}
+
 //-----CryptMessageBlock---------------------
 EncryptedMessagePart::EncryptedMessagePart(ObjectTreeParser *otp, const QString &text, const QGpgME::Protocol *cryptoProto, const QString &fromAddress, KMime::Content *node)
     : MessagePart(otp, text)
@@ -1138,6 +1054,11 @@ bool EncryptedMessagePart::isDecryptable() const
     return partMetaData()->isDecryptable;
 }
 
+bool EncryptedMessagePart::isNoSecKey() const
+{
+    return mNoSecKey;
+}
+
 bool EncryptedMessagePart::passphraseError() const
 {
     return mPassphraseError;
@@ -1385,6 +1306,21 @@ QString EncryptedMessagePart::text() const
     }
 }
 
+const QGpgME::Protocol *EncryptedMessagePart::cryptoProto() const
+{
+    return mCryptoProto;
+}
+
+QString EncryptedMessagePart::fromAddress() const
+{
+    return mFromAddress;
+}
+
+const std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key> > &EncryptedMessagePart::decryptRecipients() const
+{
+    return mDecryptRecipients;
+}
+
 EncapsulatedRfc822MessagePart::EncapsulatedRfc822MessagePart(ObjectTreeParser *otp, KMime::Content *node, const KMime::Message::Ptr &message)
     : MessagePart(otp, QString())
     , mMessage(message)
@@ -1421,3 +1357,8 @@ QString EncapsulatedRfc822MessagePart::text() const
 void EncapsulatedRfc822MessagePart::fix() const
 {
 }
+
+const KMime::Message::Ptr EncapsulatedRfc822MessagePart::message() const
+{
+    return mMessage;
+}
