@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,8 +60,8 @@ TemplatesConfiguration::TemplatesConfiguration(QWidget *parent, const QString &n
     connect(lineEdit_quote, &QLineEdit::textChanged,
             this, &TemplatesConfiguration::slotTextChanged);
 
-    connect(mInsertCommand, SIGNAL(insertCommand(QString,int)),
-            this, SLOT(slotInsertCommand(QString,int)));
+    connect(mInsertCommand, QOverload<const QString &, int>::of(&TemplateParser::TemplatesInsertCommandPushButton::insertCommand),
+            this, &TemplatesConfiguration::slotInsertCommand);
 
     d->mHelpString
         = i18n("<p>Here you can create and manage templates to use when "
@@ -382,8 +382,8 @@ void TemplatesConfiguration::slotInsertCommand(const QString &cmd, int adjustCur
 
     // qCDebug(TEMPLATEPARSER_LOG) << "Insert command:" << cmd;
     const QString editText(edit->toPlainText());
-    if ((editText.contains(QStringLiteral("%FORCEDPLAIN")) && (cmd == QLatin1String("%FORCEDHTML")))
-        || (editText.contains(QStringLiteral("%FORCEDHTML")) && (cmd == QLatin1String("%FORCEDPLAIN")))) {
+    if ((editText.contains(QLatin1String("%FORCEDPLAIN")) && (cmd == QLatin1String("%FORCEDHTML")))
+        || (editText.contains(QLatin1String("%FORCEDHTML")) && (cmd == QLatin1String("%FORCEDPLAIN")))) {
         KMessageBox::error(
             this,
             i18n("Use of \"Reply using plain text\" and \"Reply using HTML text\" in pairs"
