@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,7 +23,7 @@
 
 namespace WebEngineViewer {
 namespace WebEngineAccessKeyUtils {
-QString script();
+Q_REQUIRED_RESULT QString script();
 }
 }
 
